@@ -18,24 +18,28 @@ class TwitterAPI(object):
 	:param access_token_key: Twitter application access token key
 	:param access_token_secret: Twitter application access token secret
 	:param auth_type: "oAuth1" (default) or "oAuth2"
+	:param proxy_url: HTTPS proxy URL (ex. "https://USER:PASSWORD@SERVER:PORT")
 	"""
 	
-	def __init__(self, consumer_key=None, consumer_secret=None, access_token_key=None, access_token_secret=None, auth_type="oAuth1"):
+	def __init__(self, 
+		         consumer_key=None, consumer_secret=None, access_token_key=None, access_token_secret=None, 
+		         auth_type='oAuth1', proxy_url=None):
 		"""Initialize with your Twitter application credentials"""
-		if auth_type is "oAuth1":
+		self.proxies = {'https':proxy_url} if proxy_url else None
+		if auth_type is 'oAuth1':
 			if not all([consumer_key, consumer_secret, access_token_key, access_token_secret]):
-				raise Exception("Missing authentication parameter.")
+				raise Exception('Missing authentication parameter.')
 			self.auth = OAuth1(consumer_key, consumer_secret, access_token_key, access_token_secret)
-		elif auth_type is "oAuth2":
+		elif auth_type is 'oAuth2':
 			if not all([consumer_key, consumer_secret]):
 				raise Exception("Missing authentication parameter.")
-			self.auth = OAuth2(consumer_key, consumer_secret)
-				
+			self.auth = OAuth2(consumer_key, consumer_secret, proxies=self.proxies)
+
 	def _prepare_url(self, subdomain, path):
 		return '%s://%s.%s/%s/%s.json' % (PROTOCOL, subdomain, DOMAIN, VERSION, path)
 		
 	def _get_endpoint(self, resource):
-		""" Substitute any parameters in the resource path with :PARAM."""
+		"""Substitute any parameters in the resource path with :PARAM."""
 		if ':' in resource:
 			parts = resource.split('/')
 			# embedded parameters start with ':'
@@ -71,7 +75,7 @@ class TwitterAPI(object):
 			timeout = REST_SOCKET_TIMEOUT
 		else:
 			raise Exception('"%s" is not valid endpoint' % resource)
-		r = session.request(method, url, params=params, timeout=timeout, files=files)
+		r = session.request(method, url, params=params, timeout=timeout, files=files, proxies=self.proxies)
 		return TwitterResponse(r, session.stream)
 
 
